.. image:: https://img.shields.io/pypi/v/seed.svg
    :target: https://badge.fury.io/py/seed

.. image:: https://img.shields.io/pypi/dm/seed.svg
    :target: https://pypi.python.org/pypi/seed

.. image:: https://img.shields.io/github/license/adamcharnock/seed.svg
    :target: https://pypi.python.org/pypi/seed/

.. image:: https://img.shields.io/travis/adamcharnock/seed.svg
    :target: https://travis-ci.org/adamcharnock/seed/

.. image:: https://coveralls.io/repos/adamcharnock/seed/badge.svg
    :target: https://coveralls.io/r/adamcharnock/seed/


Documentation
=============

Documentation can be found here:

http://seed.readthedocs.org

